#!/bin/bash

VNXOPTIONS=''

# Parse command line options
while getopts ":n" opt; do
    case $opt in

    n)
        VNXOPTIONS="$VNXOPTIONS -n"
        ;;

    *)
        echo ""
        echo "ERROR: Invalid option -$OPTARG" >&2
        #echo "$USAGE"
        exit 1
        ;;

    esac
done


SINCONSOLAS="-n"

# Creamos TMPDIR unico, borrando previamente los anteriores
rm -rf /tmp/rdor-t3-pop??????
TMPDIR=$( mktemp -d /tmp/rdor-t3-popXXXXXX )
chmod 755 $TMPDIR

#TMPDIR='/tmp/.rdor3'
B="$TMPDIR/comprueba-rdor3"
INTERVMDELAY=0

SEP="------------------------------------------------------------------"

START=$(date +%s)
mkdir -p $TMPDIR
rm -rf $TMPDIR/*


function crea_tunel () {

  HOSTNAME=$( hostname )
  #HOSTNAME=l351
  #echo "Hostname=$HOSTNAME"

  case "$HOSTNAME" in
      vnx*lab )
          echo "--"
          echo "-- Escenario corriendo en maquina virtual ($HOSTNAME)" 
          echo "--"

          # Configuramos VPN y arrancamos tinc
          echo "-- tar xfvz tinc-pop?ra???.tgz"
          tar xfvz tinc-pop?ra???.tgz
          sudo killall tincd
          #sudo /etc/init.d/tinc stop
          sudo rm -rf /etc/tinc/*
          sudo mv pop?ra???/* /etc/tinc
          #sudo /etc/init.d/tinc restart
          for t in $( ls -d /etc/tinc/*/ ); do TNAME=$( basename $t ); sudo tincd --net=$TNAME; done

          # Descomprimimos escenario
          echo "unzip -o -d $TMPDIR rdor*.zip"
          unzip -o -d $TMPDIR rdor*.zip

          SCENARIO=$( ls $TMPDIR/rdor3*/*.xml | grep -v conf)

          ;;

      l[0-9][0-9][0-9] ) 
          echo "--"
          echo "-- Escenario corriendo en el laboratorio ($HOSTNAME)"
          echo "--"

          # Configuramos VPN y arrancamos tinc

          #TMPDIR=$( mktemp -d /tmp/rdor-t3-popXXXXXX )
          #chmod 755 $TMPDIR

          cp tinc-pop?ra???.tgz $TMPDIR
          pushd $TMPDIR
          tar xfz tinc-pop?ra???.tgz

          POPDIR=$( ls -d1 ${TMPDIR}/pop?ra*/pop?net )
          POPNAME=$( ls -d1 ${TMPDIR}/pop*/pop?net | xargs basename )

          echo -- POPNAME=$POPNAME, POPDIR=$POPDIR
          sudo tincd -c $POPDIR

          popd
   
          # Descomprimimos escenario
          echo "-- unzip -o -d $TMPDIR rdor*.zip"
          unzip -o -d $TMPDIR rdor*.zip

          SCENARIO=$( ls $TMPDIR/rdor3*/*.xml | grep -v conf)
echo "SCENARIO=$SCENARIO"

          #POP=$( cat $SCENARIO | sed -n '/net="pop"/{n;p}' | sed -e 's/.*>10\.\(.*\)0\.0.*<.*/\1/')
          #ASN=$( cat $SCENARIO | sed -n '/net="pop"/{n;p}' | sed -e 's/.*>10\.[0-9]\+\.[0-9]\+\.\(.*\)<.*/\1/' )

          #echo "POP=$POP"
          #echo "ASN=$ASN"

          #OLDLINE="<net name=\"pop\" mode=\"virtual_bridge\" type=\"lan\" external=\"pop${POP}net\"/>"
          #NEWLINE="<net name=\"pop\" mode=\"virtual_bridge\" type=\"lan\" external=\"eth1\" vlan=\"70${POP}\"/>"
          #sed -i -e "s#$OLDLINE#$NEWLINE#" $SCENARIO

          ;;

    * ) 

    echo "-- ERROR: Ordenador desconocido"
    exit 1
  esac
}

# Creamos script comprueba-rdor3
cat > $B << "FIN-B"
#!/bin/bash

RETRYCHECKVM=5
RETRYCHECKDELAY=5

echo "Comprobando arranque de routers y hosts..."
VMS="A B C D E H1 H2"
echo $VMS

for VM in $VMS; do

  echo "$VM:"
  for ((i=$RETRYCHECKVM; i>0; i--)); do
    #echo "nmap -p ssh $VM | grep ssh | grep open"
    RES=$( nmap -p ssh $VM | grep ssh | grep open )
    #echo "$i - RES=$RES"
    if [ "$RES" != "" ]; then
      echo " arrancado"
      break
    elif [ "$i" -eq 1 ]; then
      echo "ERROR"
      FALLOS="$FALLOS $VM"
      break
    fi
    echo " x"
    sleep $RETRYCHECKDELAY
  done
done

echo $SEP
if [ "$FALLOS" = "" ]; then
    echo "Escenario arrancado correctamente."
else
    echo "ERROR: algunos sistemas no arrancaron correctamente ($FALLOS )"
    echo "       Rearranque el escenario de nuevo"
fi
echo $SEP

FIN-B

function limpia () {

PIDS=$( ps uaxww | grep "sudo vnx" | grep -v grep | awk '{ print $2 }' )
if [ "$PIDS" ]; then
    echo "-- Matando procesos vnx:" $PIDS
    sudo kill -9 $PIDS
else
    echo "-- No hay procesos vnx"
fi

PIDS=$( ps uaxww | grep "comprueba-rdor3" | grep -v grep | awk '{ print $2 }' )
if [ "$PIDS" ]; then
    echo "-- Matando procesos comprueba-rdor3:" $PIDS
    sudo kill -9 $PIDS
else
    echo "-- No hay procesos comprueba-rdor3"
fi

#sudo vnx -D
echo "SCENARIO=$SCENARIO"
sudo vnx -f $SCENARIO -v -P -D 2>&1

}


( crea_tunel; limpia; sudo vnx -f $SCENARIO -v -t --intervm-delay $INTERVMDELAY $VNXOPTIONS 2>&1; echo ''; echo "$SEP"; END=$(date +%s); DIFF=$(( $END - $START)); echo "Duración total: $DIFF segundos"; echo "$SEP" ) 2>&1 | yad --text-info --tail --title 'Arrancando trabajo 3 RDOR...' --height 400 --width 800 --fontname="Monospace 7" --wrap &
